Documentation
¶
Overview ¶
Package pluginv1 contains the generated protobuf and gRPC code for the AWF plugin protocol. This file will be overwritten by `make proto-gen` (T005) once plugin.proto is defined (T004).
Index ¶
- Constants
- Variables
- func RegisterOperationServiceServer(s grpc.ServiceRegistrar, srv OperationServiceServer)
- func RegisterPluginServiceServer(s grpc.ServiceRegistrar, srv PluginServiceServer)
- func RegisterStepTypeServiceServer(s grpc.ServiceRegistrar, srv StepTypeServiceServer)
- func RegisterValidatorServiceServer(s grpc.ServiceRegistrar, srv ValidatorServiceServer)
- type ExecuteRequest
- func (*ExecuteRequest) Descriptor() ([]byte, []int)deprecated
- func (x *ExecuteRequest) GetInputs() map[string][]byte
- func (x *ExecuteRequest) GetOperation() string
- func (*ExecuteRequest) ProtoMessage()
- func (x *ExecuteRequest) ProtoReflect() protoreflect.Message
- func (x *ExecuteRequest) Reset()
- func (x *ExecuteRequest) String() string
- type ExecuteResponse
- func (*ExecuteResponse) Descriptor() ([]byte, []int)deprecated
- func (x *ExecuteResponse) GetData() map[string][]byte
- func (x *ExecuteResponse) GetError() string
- func (x *ExecuteResponse) GetOutput() string
- func (x *ExecuteResponse) GetSuccess() bool
- func (*ExecuteResponse) ProtoMessage()
- func (x *ExecuteResponse) ProtoReflect() protoreflect.Message
- func (x *ExecuteResponse) Reset()
- func (x *ExecuteResponse) String() string
- type ExecuteStepRequest
- func (*ExecuteStepRequest) Descriptor() ([]byte, []int)deprecated
- func (x *ExecuteStepRequest) GetConfig() []byte
- func (x *ExecuteStepRequest) GetInputs() []byte
- func (x *ExecuteStepRequest) GetStepName() string
- func (x *ExecuteStepRequest) GetStepType() string
- func (*ExecuteStepRequest) ProtoMessage()
- func (x *ExecuteStepRequest) ProtoReflect() protoreflect.Message
- func (x *ExecuteStepRequest) Reset()
- func (x *ExecuteStepRequest) String() string
- type ExecuteStepResponse
- func (*ExecuteStepResponse) Descriptor() ([]byte, []int)deprecated
- func (x *ExecuteStepResponse) GetData() []byte
- func (x *ExecuteStepResponse) GetExitCode() int32
- func (x *ExecuteStepResponse) GetOutput() string
- func (*ExecuteStepResponse) ProtoMessage()
- func (x *ExecuteStepResponse) ProtoReflect() protoreflect.Message
- func (x *ExecuteStepResponse) Reset()
- func (x *ExecuteStepResponse) String() string
- type GetInfoRequest
- type GetInfoResponse
- func (*GetInfoResponse) Descriptor() ([]byte, []int)deprecated
- func (x *GetInfoResponse) GetCapabilities() []string
- func (x *GetInfoResponse) GetDescription() string
- func (x *GetInfoResponse) GetName() string
- func (x *GetInfoResponse) GetVersion() string
- func (*GetInfoResponse) ProtoMessage()
- func (x *GetInfoResponse) ProtoReflect() protoreflect.Message
- func (x *GetInfoResponse) Reset()
- func (x *GetInfoResponse) String() string
- type GetOperationRequest
- func (*GetOperationRequest) Descriptor() ([]byte, []int)deprecated
- func (x *GetOperationRequest) GetName() string
- func (*GetOperationRequest) ProtoMessage()
- func (x *GetOperationRequest) ProtoReflect() protoreflect.Message
- func (x *GetOperationRequest) Reset()
- func (x *GetOperationRequest) String() string
- type GetOperationResponse
- func (*GetOperationResponse) Descriptor() ([]byte, []int)deprecated
- func (x *GetOperationResponse) GetOperation() *OperationSchema
- func (*GetOperationResponse) ProtoMessage()
- func (x *GetOperationResponse) ProtoReflect() protoreflect.Message
- func (x *GetOperationResponse) Reset()
- func (x *GetOperationResponse) String() string
- type InitRequest
- type InitResponse
- type InputSchema
- func (*InputSchema) Descriptor() ([]byte, []int)deprecated
- func (x *InputSchema) GetDefault() string
- func (x *InputSchema) GetDescription() string
- func (x *InputSchema) GetName() string
- func (x *InputSchema) GetRequired() bool
- func (x *InputSchema) GetType() string
- func (x *InputSchema) GetValidation() string
- func (*InputSchema) ProtoMessage()
- func (x *InputSchema) ProtoReflect() protoreflect.Message
- func (x *InputSchema) Reset()
- func (x *InputSchema) String() string
- type ListOperationsRequest
- type ListOperationsResponse
- func (*ListOperationsResponse) Descriptor() ([]byte, []int)deprecated
- func (x *ListOperationsResponse) GetOperations() []*OperationSchema
- func (*ListOperationsResponse) ProtoMessage()
- func (x *ListOperationsResponse) ProtoReflect() protoreflect.Message
- func (x *ListOperationsResponse) Reset()
- func (x *ListOperationsResponse) String() string
- type ListStepTypesRequest
- type ListStepTypesResponse
- func (*ListStepTypesResponse) Descriptor() ([]byte, []int)deprecated
- func (x *ListStepTypesResponse) GetStepTypes() []*StepTypeInfo
- func (*ListStepTypesResponse) ProtoMessage()
- func (x *ListStepTypesResponse) ProtoReflect() protoreflect.Message
- func (x *ListStepTypesResponse) Reset()
- func (x *ListStepTypesResponse) String() string
- type OperationSchema
- func (*OperationSchema) Descriptor() ([]byte, []int)deprecated
- func (x *OperationSchema) GetDescription() string
- func (x *OperationSchema) GetInputs() []*InputSchema
- func (x *OperationSchema) GetName() string
- func (x *OperationSchema) GetOutputs() []*OutputSchema
- func (*OperationSchema) ProtoMessage()
- func (x *OperationSchema) ProtoReflect() protoreflect.Message
- func (x *OperationSchema) Reset()
- func (x *OperationSchema) String() string
- type OperationServiceClient
- type OperationServiceServer
- type OutputSchema
- func (*OutputSchema) Descriptor() ([]byte, []int)deprecated
- func (x *OutputSchema) GetDescription() string
- func (x *OutputSchema) GetName() string
- func (x *OutputSchema) GetType() string
- func (*OutputSchema) ProtoMessage()
- func (x *OutputSchema) ProtoReflect() protoreflect.Message
- func (x *OutputSchema) Reset()
- func (x *OutputSchema) String() string
- type PluginServiceClient
- type PluginServiceServer
- type Severity
- type ShutdownRequest
- type ShutdownResponse
- type StepTypeInfo
- func (*StepTypeInfo) Descriptor() ([]byte, []int)deprecated
- func (x *StepTypeInfo) GetDescription() string
- func (x *StepTypeInfo) GetName() string
- func (*StepTypeInfo) ProtoMessage()
- func (x *StepTypeInfo) ProtoReflect() protoreflect.Message
- func (x *StepTypeInfo) Reset()
- func (x *StepTypeInfo) String() string
- type StepTypeServiceClient
- type StepTypeServiceServer
- type UnimplementedOperationServiceServer
- func (UnimplementedOperationServiceServer) Execute(context.Context, *ExecuteRequest) (*ExecuteResponse, error)
- func (UnimplementedOperationServiceServer) GetOperation(context.Context, *GetOperationRequest) (*GetOperationResponse, error)
- func (UnimplementedOperationServiceServer) ListOperations(context.Context, *ListOperationsRequest) (*ListOperationsResponse, error)
- type UnimplementedPluginServiceServer
- func (UnimplementedPluginServiceServer) GetInfo(context.Context, *GetInfoRequest) (*GetInfoResponse, error)
- func (UnimplementedPluginServiceServer) Init(context.Context, *InitRequest) (*InitResponse, error)
- func (UnimplementedPluginServiceServer) Shutdown(context.Context, *ShutdownRequest) (*ShutdownResponse, error)
- type UnimplementedStepTypeServiceServer
- type UnimplementedValidatorServiceServer
- type UnsafeOperationServiceServer
- type UnsafePluginServiceServer
- type UnsafeStepTypeServiceServer
- type UnsafeValidatorServiceServer
- type ValidateStepRequest
- func (*ValidateStepRequest) Descriptor() ([]byte, []int)deprecated
- func (x *ValidateStepRequest) GetStepName() string
- func (x *ValidateStepRequest) GetWorkflowJson() []byte
- func (*ValidateStepRequest) ProtoMessage()
- func (x *ValidateStepRequest) ProtoReflect() protoreflect.Message
- func (x *ValidateStepRequest) Reset()
- func (x *ValidateStepRequest) String() string
- type ValidateStepResponse
- func (*ValidateStepResponse) Descriptor() ([]byte, []int)deprecated
- func (x *ValidateStepResponse) GetIssues() []*ValidationIssue
- func (*ValidateStepResponse) ProtoMessage()
- func (x *ValidateStepResponse) ProtoReflect() protoreflect.Message
- func (x *ValidateStepResponse) Reset()
- func (x *ValidateStepResponse) String() string
- type ValidateWorkflowRequest
- func (*ValidateWorkflowRequest) Descriptor() ([]byte, []int)deprecated
- func (x *ValidateWorkflowRequest) GetWorkflowJson() []byte
- func (*ValidateWorkflowRequest) ProtoMessage()
- func (x *ValidateWorkflowRequest) ProtoReflect() protoreflect.Message
- func (x *ValidateWorkflowRequest) Reset()
- func (x *ValidateWorkflowRequest) String() string
- type ValidateWorkflowResponse
- func (*ValidateWorkflowResponse) Descriptor() ([]byte, []int)deprecated
- func (x *ValidateWorkflowResponse) GetIssues() []*ValidationIssue
- func (*ValidateWorkflowResponse) ProtoMessage()
- func (x *ValidateWorkflowResponse) ProtoReflect() protoreflect.Message
- func (x *ValidateWorkflowResponse) Reset()
- func (x *ValidateWorkflowResponse) String() string
- type ValidationIssue
- func (*ValidationIssue) Descriptor() ([]byte, []int)deprecated
- func (x *ValidationIssue) GetField() string
- func (x *ValidationIssue) GetMessage() string
- func (x *ValidationIssue) GetSeverity() Severity
- func (x *ValidationIssue) GetStep() string
- func (*ValidationIssue) ProtoMessage()
- func (x *ValidationIssue) ProtoReflect() protoreflect.Message
- func (x *ValidationIssue) Reset()
- func (x *ValidationIssue) String() string
- type ValidatorServiceClient
- type ValidatorServiceServer
Constants ¶
const ( PluginService_GetInfo_FullMethodName = "/plugin.v1.PluginService/GetInfo" PluginService_Init_FullMethodName = "/plugin.v1.PluginService/Init" PluginService_Shutdown_FullMethodName = "/plugin.v1.PluginService/Shutdown" )
const ( OperationService_ListOperations_FullMethodName = "/plugin.v1.OperationService/ListOperations" OperationService_GetOperation_FullMethodName = "/plugin.v1.OperationService/GetOperation" OperationService_Execute_FullMethodName = "/plugin.v1.OperationService/Execute" )
const ( ValidatorService_ValidateWorkflow_FullMethodName = "/plugin.v1.ValidatorService/ValidateWorkflow" ValidatorService_ValidateStep_FullMethodName = "/plugin.v1.ValidatorService/ValidateStep" )
const ( StepTypeService_ListStepTypes_FullMethodName = "/plugin.v1.StepTypeService/ListStepTypes" StepTypeService_ExecuteStep_FullMethodName = "/plugin.v1.StepTypeService/ExecuteStep" )
Variables ¶
var ( Severity_name = map[int32]string{ 0: "SEVERITY_UNSPECIFIED", 1: "SEVERITY_WARNING", 2: "SEVERITY_ERROR", 3: "SEVERITY_INFO", } Severity_value = map[string]int32{ "SEVERITY_UNSPECIFIED": 0, "SEVERITY_WARNING": 1, "SEVERITY_ERROR": 2, "SEVERITY_INFO": 3, } )
Enum value maps for Severity.
var File_proto_plugin_v1_plugin_proto protoreflect.FileDescriptor
var OperationService_ServiceDesc = grpc.ServiceDesc{ ServiceName: "plugin.v1.OperationService", HandlerType: (*OperationServiceServer)(nil), Methods: []grpc.MethodDesc{ { MethodName: "ListOperations", Handler: _OperationService_ListOperations_Handler, }, { MethodName: "GetOperation", Handler: _OperationService_GetOperation_Handler, }, { MethodName: "Execute", Handler: _OperationService_Execute_Handler, }, }, Streams: []grpc.StreamDesc{}, Metadata: "proto/plugin/v1/plugin.proto", }
OperationService_ServiceDesc is the grpc.ServiceDesc for OperationService service. It's only intended for direct use with grpc.RegisterService, and not to be introspected or modified (even as a copy)
var PluginService_ServiceDesc = grpc.ServiceDesc{ ServiceName: "plugin.v1.PluginService", HandlerType: (*PluginServiceServer)(nil), Methods: []grpc.MethodDesc{ { MethodName: "GetInfo", Handler: _PluginService_GetInfo_Handler, }, { MethodName: "Init", Handler: _PluginService_Init_Handler, }, { MethodName: "Shutdown", Handler: _PluginService_Shutdown_Handler, }, }, Streams: []grpc.StreamDesc{}, Metadata: "proto/plugin/v1/plugin.proto", }
PluginService_ServiceDesc is the grpc.ServiceDesc for PluginService service. It's only intended for direct use with grpc.RegisterService, and not to be introspected or modified (even as a copy)
var StepTypeService_ServiceDesc = grpc.ServiceDesc{ ServiceName: "plugin.v1.StepTypeService", HandlerType: (*StepTypeServiceServer)(nil), Methods: []grpc.MethodDesc{ { MethodName: "ListStepTypes", Handler: _StepTypeService_ListStepTypes_Handler, }, { MethodName: "ExecuteStep", Handler: _StepTypeService_ExecuteStep_Handler, }, }, Streams: []grpc.StreamDesc{}, Metadata: "proto/plugin/v1/plugin.proto", }
StepTypeService_ServiceDesc is the grpc.ServiceDesc for StepTypeService service. It's only intended for direct use with grpc.RegisterService, and not to be introspected or modified (even as a copy)
var ValidatorService_ServiceDesc = grpc.ServiceDesc{ ServiceName: "plugin.v1.ValidatorService", HandlerType: (*ValidatorServiceServer)(nil), Methods: []grpc.MethodDesc{ { MethodName: "ValidateWorkflow", Handler: _ValidatorService_ValidateWorkflow_Handler, }, { MethodName: "ValidateStep", Handler: _ValidatorService_ValidateStep_Handler, }, }, Streams: []grpc.StreamDesc{}, Metadata: "proto/plugin/v1/plugin.proto", }
ValidatorService_ServiceDesc is the grpc.ServiceDesc for ValidatorService service. It's only intended for direct use with grpc.RegisterService, and not to be introspected or modified (even as a copy)
Functions ¶
func RegisterOperationServiceServer ¶
func RegisterOperationServiceServer(s grpc.ServiceRegistrar, srv OperationServiceServer)
func RegisterPluginServiceServer ¶
func RegisterPluginServiceServer(s grpc.ServiceRegistrar, srv PluginServiceServer)
func RegisterStepTypeServiceServer ¶ added in v0.5.0
func RegisterStepTypeServiceServer(s grpc.ServiceRegistrar, srv StepTypeServiceServer)
func RegisterValidatorServiceServer ¶ added in v0.5.0
func RegisterValidatorServiceServer(s grpc.ServiceRegistrar, srv ValidatorServiceServer)
Types ¶
type ExecuteRequest ¶
type ExecuteRequest struct {
Operation string `protobuf:"bytes,1,opt,name=operation,proto3" json:"operation,omitempty"`
Inputs map[string][]byte `` /* 139-byte string literal not displayed */
// contains filtered or unexported fields
}
func (*ExecuteRequest) Descriptor
deprecated
func (*ExecuteRequest) Descriptor() ([]byte, []int)
Deprecated: Use ExecuteRequest.ProtoReflect.Descriptor instead.
func (*ExecuteRequest) GetInputs ¶
func (x *ExecuteRequest) GetInputs() map[string][]byte
func (*ExecuteRequest) GetOperation ¶
func (x *ExecuteRequest) GetOperation() string
func (*ExecuteRequest) ProtoMessage ¶
func (*ExecuteRequest) ProtoMessage()
func (*ExecuteRequest) ProtoReflect ¶
func (x *ExecuteRequest) ProtoReflect() protoreflect.Message
func (*ExecuteRequest) Reset ¶
func (x *ExecuteRequest) Reset()
func (*ExecuteRequest) String ¶
func (x *ExecuteRequest) String() string
type ExecuteResponse ¶
type ExecuteResponse struct {
Success bool `protobuf:"varint,1,opt,name=success,proto3" json:"success,omitempty"`
Output string `protobuf:"bytes,2,opt,name=output,proto3" json:"output,omitempty"`
Data map[string][]byte `` /* 135-byte string literal not displayed */
Error string `protobuf:"bytes,4,opt,name=error,proto3" json:"error,omitempty"`
// contains filtered or unexported fields
}
func (*ExecuteResponse) Descriptor
deprecated
func (*ExecuteResponse) Descriptor() ([]byte, []int)
Deprecated: Use ExecuteResponse.ProtoReflect.Descriptor instead.
func (*ExecuteResponse) GetData ¶
func (x *ExecuteResponse) GetData() map[string][]byte
func (*ExecuteResponse) GetError ¶
func (x *ExecuteResponse) GetError() string
func (*ExecuteResponse) GetOutput ¶
func (x *ExecuteResponse) GetOutput() string
func (*ExecuteResponse) GetSuccess ¶
func (x *ExecuteResponse) GetSuccess() bool
func (*ExecuteResponse) ProtoMessage ¶
func (*ExecuteResponse) ProtoMessage()
func (*ExecuteResponse) ProtoReflect ¶
func (x *ExecuteResponse) ProtoReflect() protoreflect.Message
func (*ExecuteResponse) Reset ¶
func (x *ExecuteResponse) Reset()
func (*ExecuteResponse) String ¶
func (x *ExecuteResponse) String() string
type ExecuteStepRequest ¶ added in v0.5.0
type ExecuteStepRequest struct {
StepName string `protobuf:"bytes,1,opt,name=step_name,json=stepName,proto3" json:"step_name,omitempty"`
StepType string `protobuf:"bytes,2,opt,name=step_type,json=stepType,proto3" json:"step_type,omitempty"`
Config []byte `protobuf:"bytes,3,opt,name=config,proto3" json:"config,omitempty"`
Inputs []byte `protobuf:"bytes,4,opt,name=inputs,proto3" json:"inputs,omitempty"`
// contains filtered or unexported fields
}
func (*ExecuteStepRequest) Descriptor
deprecated
added in
v0.5.0
func (*ExecuteStepRequest) Descriptor() ([]byte, []int)
Deprecated: Use ExecuteStepRequest.ProtoReflect.Descriptor instead.
func (*ExecuteStepRequest) GetConfig ¶ added in v0.5.0
func (x *ExecuteStepRequest) GetConfig() []byte
func (*ExecuteStepRequest) GetInputs ¶ added in v0.5.0
func (x *ExecuteStepRequest) GetInputs() []byte
func (*ExecuteStepRequest) GetStepName ¶ added in v0.5.0
func (x *ExecuteStepRequest) GetStepName() string
func (*ExecuteStepRequest) GetStepType ¶ added in v0.5.0
func (x *ExecuteStepRequest) GetStepType() string
func (*ExecuteStepRequest) ProtoMessage ¶ added in v0.5.0
func (*ExecuteStepRequest) ProtoMessage()
func (*ExecuteStepRequest) ProtoReflect ¶ added in v0.5.0
func (x *ExecuteStepRequest) ProtoReflect() protoreflect.Message
func (*ExecuteStepRequest) Reset ¶ added in v0.5.0
func (x *ExecuteStepRequest) Reset()
func (*ExecuteStepRequest) String ¶ added in v0.5.0
func (x *ExecuteStepRequest) String() string
type ExecuteStepResponse ¶ added in v0.5.0
type ExecuteStepResponse struct {
Output string `protobuf:"bytes,1,opt,name=output,proto3" json:"output,omitempty"`
Data []byte `protobuf:"bytes,2,opt,name=data,proto3" json:"data,omitempty"`
ExitCode int32 `protobuf:"varint,3,opt,name=exit_code,json=exitCode,proto3" json:"exit_code,omitempty"`
// contains filtered or unexported fields
}
func (*ExecuteStepResponse) Descriptor
deprecated
added in
v0.5.0
func (*ExecuteStepResponse) Descriptor() ([]byte, []int)
Deprecated: Use ExecuteStepResponse.ProtoReflect.Descriptor instead.
func (*ExecuteStepResponse) GetData ¶ added in v0.5.0
func (x *ExecuteStepResponse) GetData() []byte
func (*ExecuteStepResponse) GetExitCode ¶ added in v0.5.0
func (x *ExecuteStepResponse) GetExitCode() int32
func (*ExecuteStepResponse) GetOutput ¶ added in v0.5.0
func (x *ExecuteStepResponse) GetOutput() string
func (*ExecuteStepResponse) ProtoMessage ¶ added in v0.5.0
func (*ExecuteStepResponse) ProtoMessage()
func (*ExecuteStepResponse) ProtoReflect ¶ added in v0.5.0
func (x *ExecuteStepResponse) ProtoReflect() protoreflect.Message
func (*ExecuteStepResponse) Reset ¶ added in v0.5.0
func (x *ExecuteStepResponse) Reset()
func (*ExecuteStepResponse) String ¶ added in v0.5.0
func (x *ExecuteStepResponse) String() string
type GetInfoRequest ¶
type GetInfoRequest struct {
// contains filtered or unexported fields
}
func (*GetInfoRequest) Descriptor
deprecated
func (*GetInfoRequest) Descriptor() ([]byte, []int)
Deprecated: Use GetInfoRequest.ProtoReflect.Descriptor instead.
func (*GetInfoRequest) ProtoMessage ¶
func (*GetInfoRequest) ProtoMessage()
func (*GetInfoRequest) ProtoReflect ¶
func (x *GetInfoRequest) ProtoReflect() protoreflect.Message
func (*GetInfoRequest) Reset ¶
func (x *GetInfoRequest) Reset()
func (*GetInfoRequest) String ¶
func (x *GetInfoRequest) String() string
type GetInfoResponse ¶
type GetInfoResponse struct {
Name string `protobuf:"bytes,1,opt,name=name,proto3" json:"name,omitempty"`
Version string `protobuf:"bytes,2,opt,name=version,proto3" json:"version,omitempty"`
Description string `protobuf:"bytes,3,opt,name=description,proto3" json:"description,omitempty"`
Capabilities []string `protobuf:"bytes,4,rep,name=capabilities,proto3" json:"capabilities,omitempty"`
// contains filtered or unexported fields
}
func (*GetInfoResponse) Descriptor
deprecated
func (*GetInfoResponse) Descriptor() ([]byte, []int)
Deprecated: Use GetInfoResponse.ProtoReflect.Descriptor instead.
func (*GetInfoResponse) GetCapabilities ¶
func (x *GetInfoResponse) GetCapabilities() []string
func (*GetInfoResponse) GetDescription ¶
func (x *GetInfoResponse) GetDescription() string
func (*GetInfoResponse) GetName ¶
func (x *GetInfoResponse) GetName() string
func (*GetInfoResponse) GetVersion ¶
func (x *GetInfoResponse) GetVersion() string
func (*GetInfoResponse) ProtoMessage ¶
func (*GetInfoResponse) ProtoMessage()
func (*GetInfoResponse) ProtoReflect ¶
func (x *GetInfoResponse) ProtoReflect() protoreflect.Message
func (*GetInfoResponse) Reset ¶
func (x *GetInfoResponse) Reset()
func (*GetInfoResponse) String ¶
func (x *GetInfoResponse) String() string
type GetOperationRequest ¶
type GetOperationRequest struct {
Name string `protobuf:"bytes,1,opt,name=name,proto3" json:"name,omitempty"`
// contains filtered or unexported fields
}
func (*GetOperationRequest) Descriptor
deprecated
func (*GetOperationRequest) Descriptor() ([]byte, []int)
Deprecated: Use GetOperationRequest.ProtoReflect.Descriptor instead.
func (*GetOperationRequest) GetName ¶
func (x *GetOperationRequest) GetName() string
func (*GetOperationRequest) ProtoMessage ¶
func (*GetOperationRequest) ProtoMessage()
func (*GetOperationRequest) ProtoReflect ¶
func (x *GetOperationRequest) ProtoReflect() protoreflect.Message
func (*GetOperationRequest) Reset ¶
func (x *GetOperationRequest) Reset()
func (*GetOperationRequest) String ¶
func (x *GetOperationRequest) String() string
type GetOperationResponse ¶
type GetOperationResponse struct {
Operation *OperationSchema `protobuf:"bytes,1,opt,name=operation,proto3" json:"operation,omitempty"`
// contains filtered or unexported fields
}
func (*GetOperationResponse) Descriptor
deprecated
func (*GetOperationResponse) Descriptor() ([]byte, []int)
Deprecated: Use GetOperationResponse.ProtoReflect.Descriptor instead.
func (*GetOperationResponse) GetOperation ¶
func (x *GetOperationResponse) GetOperation() *OperationSchema
func (*GetOperationResponse) ProtoMessage ¶
func (*GetOperationResponse) ProtoMessage()
func (*GetOperationResponse) ProtoReflect ¶
func (x *GetOperationResponse) ProtoReflect() protoreflect.Message
func (*GetOperationResponse) Reset ¶
func (x *GetOperationResponse) Reset()
func (*GetOperationResponse) String ¶
func (x *GetOperationResponse) String() string
type InitRequest ¶
type InitRequest struct {
Config map[string][]byte `` /* 139-byte string literal not displayed */
// contains filtered or unexported fields
}
func (*InitRequest) Descriptor
deprecated
func (*InitRequest) Descriptor() ([]byte, []int)
Deprecated: Use InitRequest.ProtoReflect.Descriptor instead.
func (*InitRequest) GetConfig ¶
func (x *InitRequest) GetConfig() map[string][]byte
func (*InitRequest) ProtoMessage ¶
func (*InitRequest) ProtoMessage()
func (*InitRequest) ProtoReflect ¶
func (x *InitRequest) ProtoReflect() protoreflect.Message
func (*InitRequest) Reset ¶
func (x *InitRequest) Reset()
func (*InitRequest) String ¶
func (x *InitRequest) String() string
type InitResponse ¶
type InitResponse struct {
// contains filtered or unexported fields
}
func (*InitResponse) Descriptor
deprecated
func (*InitResponse) Descriptor() ([]byte, []int)
Deprecated: Use InitResponse.ProtoReflect.Descriptor instead.
func (*InitResponse) ProtoMessage ¶
func (*InitResponse) ProtoMessage()
func (*InitResponse) ProtoReflect ¶
func (x *InitResponse) ProtoReflect() protoreflect.Message
func (*InitResponse) Reset ¶
func (x *InitResponse) Reset()
func (*InitResponse) String ¶
func (x *InitResponse) String() string
type InputSchema ¶
type InputSchema struct {
Name string `protobuf:"bytes,1,opt,name=name,proto3" json:"name,omitempty"`
Type string `protobuf:"bytes,2,opt,name=type,proto3" json:"type,omitempty"`
Required bool `protobuf:"varint,3,opt,name=required,proto3" json:"required,omitempty"`
Default string `protobuf:"bytes,4,opt,name=default,proto3" json:"default,omitempty"`
Description string `protobuf:"bytes,5,opt,name=description,proto3" json:"description,omitempty"`
Validation string `protobuf:"bytes,6,opt,name=validation,proto3" json:"validation,omitempty"`
// contains filtered or unexported fields
}
func (*InputSchema) Descriptor
deprecated
func (*InputSchema) Descriptor() ([]byte, []int)
Deprecated: Use InputSchema.ProtoReflect.Descriptor instead.
func (*InputSchema) GetDefault ¶
func (x *InputSchema) GetDefault() string
func (*InputSchema) GetDescription ¶
func (x *InputSchema) GetDescription() string
func (*InputSchema) GetName ¶
func (x *InputSchema) GetName() string
func (*InputSchema) GetRequired ¶
func (x *InputSchema) GetRequired() bool
func (*InputSchema) GetType ¶
func (x *InputSchema) GetType() string
func (*InputSchema) GetValidation ¶
func (x *InputSchema) GetValidation() string
func (*InputSchema) ProtoMessage ¶
func (*InputSchema) ProtoMessage()
func (*InputSchema) ProtoReflect ¶
func (x *InputSchema) ProtoReflect() protoreflect.Message
func (*InputSchema) Reset ¶
func (x *InputSchema) Reset()
func (*InputSchema) String ¶
func (x *InputSchema) String() string
type ListOperationsRequest ¶
type ListOperationsRequest struct {
// contains filtered or unexported fields
}
func (*ListOperationsRequest) Descriptor
deprecated
func (*ListOperationsRequest) Descriptor() ([]byte, []int)
Deprecated: Use ListOperationsRequest.ProtoReflect.Descriptor instead.
func (*ListOperationsRequest) ProtoMessage ¶
func (*ListOperationsRequest) ProtoMessage()
func (*ListOperationsRequest) ProtoReflect ¶
func (x *ListOperationsRequest) ProtoReflect() protoreflect.Message
func (*ListOperationsRequest) Reset ¶
func (x *ListOperationsRequest) Reset()
func (*ListOperationsRequest) String ¶
func (x *ListOperationsRequest) String() string
type ListOperationsResponse ¶
type ListOperationsResponse struct {
Operations []*OperationSchema `protobuf:"bytes,1,rep,name=operations,proto3" json:"operations,omitempty"`
// contains filtered or unexported fields
}
func (*ListOperationsResponse) Descriptor
deprecated
func (*ListOperationsResponse) Descriptor() ([]byte, []int)
Deprecated: Use ListOperationsResponse.ProtoReflect.Descriptor instead.
func (*ListOperationsResponse) GetOperations ¶
func (x *ListOperationsResponse) GetOperations() []*OperationSchema
func (*ListOperationsResponse) ProtoMessage ¶
func (*ListOperationsResponse) ProtoMessage()
func (*ListOperationsResponse) ProtoReflect ¶
func (x *ListOperationsResponse) ProtoReflect() protoreflect.Message
func (*ListOperationsResponse) Reset ¶
func (x *ListOperationsResponse) Reset()
func (*ListOperationsResponse) String ¶
func (x *ListOperationsResponse) String() string
type ListStepTypesRequest ¶ added in v0.5.0
type ListStepTypesRequest struct {
// contains filtered or unexported fields
}
func (*ListStepTypesRequest) Descriptor
deprecated
added in
v0.5.0
func (*ListStepTypesRequest) Descriptor() ([]byte, []int)
Deprecated: Use ListStepTypesRequest.ProtoReflect.Descriptor instead.
func (*ListStepTypesRequest) ProtoMessage ¶ added in v0.5.0
func (*ListStepTypesRequest) ProtoMessage()
func (*ListStepTypesRequest) ProtoReflect ¶ added in v0.5.0
func (x *ListStepTypesRequest) ProtoReflect() protoreflect.Message
func (*ListStepTypesRequest) Reset ¶ added in v0.5.0
func (x *ListStepTypesRequest) Reset()
func (*ListStepTypesRequest) String ¶ added in v0.5.0
func (x *ListStepTypesRequest) String() string
type ListStepTypesResponse ¶ added in v0.5.0
type ListStepTypesResponse struct {
StepTypes []*StepTypeInfo `protobuf:"bytes,1,rep,name=step_types,json=stepTypes,proto3" json:"step_types,omitempty"`
// contains filtered or unexported fields
}
func (*ListStepTypesResponse) Descriptor
deprecated
added in
v0.5.0
func (*ListStepTypesResponse) Descriptor() ([]byte, []int)
Deprecated: Use ListStepTypesResponse.ProtoReflect.Descriptor instead.
func (*ListStepTypesResponse) GetStepTypes ¶ added in v0.5.0
func (x *ListStepTypesResponse) GetStepTypes() []*StepTypeInfo
func (*ListStepTypesResponse) ProtoMessage ¶ added in v0.5.0
func (*ListStepTypesResponse) ProtoMessage()
func (*ListStepTypesResponse) ProtoReflect ¶ added in v0.5.0
func (x *ListStepTypesResponse) ProtoReflect() protoreflect.Message
func (*ListStepTypesResponse) Reset ¶ added in v0.5.0
func (x *ListStepTypesResponse) Reset()
func (*ListStepTypesResponse) String ¶ added in v0.5.0
func (x *ListStepTypesResponse) String() string
type OperationSchema ¶
type OperationSchema struct {
Name string `protobuf:"bytes,1,opt,name=name,proto3" json:"name,omitempty"`
Description string `protobuf:"bytes,2,opt,name=description,proto3" json:"description,omitempty"`
Inputs []*InputSchema `protobuf:"bytes,3,rep,name=inputs,proto3" json:"inputs,omitempty"`
Outputs []*OutputSchema `protobuf:"bytes,4,rep,name=outputs,proto3" json:"outputs,omitempty"`
// contains filtered or unexported fields
}
func (*OperationSchema) Descriptor
deprecated
func (*OperationSchema) Descriptor() ([]byte, []int)
Deprecated: Use OperationSchema.ProtoReflect.Descriptor instead.
func (*OperationSchema) GetDescription ¶
func (x *OperationSchema) GetDescription() string
func (*OperationSchema) GetInputs ¶
func (x *OperationSchema) GetInputs() []*InputSchema
func (*OperationSchema) GetName ¶
func (x *OperationSchema) GetName() string
func (*OperationSchema) GetOutputs ¶
func (x *OperationSchema) GetOutputs() []*OutputSchema
func (*OperationSchema) ProtoMessage ¶
func (*OperationSchema) ProtoMessage()
func (*OperationSchema) ProtoReflect ¶
func (x *OperationSchema) ProtoReflect() protoreflect.Message
func (*OperationSchema) Reset ¶
func (x *OperationSchema) Reset()
func (*OperationSchema) String ¶
func (x *OperationSchema) String() string
type OperationServiceClient ¶
type OperationServiceClient interface {
ListOperations(ctx context.Context, in *ListOperationsRequest, opts ...grpc.CallOption) (*ListOperationsResponse, error)
GetOperation(ctx context.Context, in *GetOperationRequest, opts ...grpc.CallOption) (*GetOperationResponse, error)
Execute(ctx context.Context, in *ExecuteRequest, opts ...grpc.CallOption) (*ExecuteResponse, error)
}
OperationServiceClient is the client API for OperationService service.
For semantics around ctx use and closing/ending streaming RPCs, please refer to https://pkg.go.dev/google.golang.org/grpc/?tab=doc#ClientConn.NewStream.
func NewOperationServiceClient ¶
func NewOperationServiceClient(cc grpc.ClientConnInterface) OperationServiceClient
type OperationServiceServer ¶
type OperationServiceServer interface {
ListOperations(context.Context, *ListOperationsRequest) (*ListOperationsResponse, error)
GetOperation(context.Context, *GetOperationRequest) (*GetOperationResponse, error)
Execute(context.Context, *ExecuteRequest) (*ExecuteResponse, error)
// contains filtered or unexported methods
}
OperationServiceServer is the server API for OperationService service. All implementations must embed UnimplementedOperationServiceServer for forward compatibility.
type OutputSchema ¶
type OutputSchema struct {
Name string `protobuf:"bytes,1,opt,name=name,proto3" json:"name,omitempty"`
Type string `protobuf:"bytes,2,opt,name=type,proto3" json:"type,omitempty"`
Description string `protobuf:"bytes,3,opt,name=description,proto3" json:"description,omitempty"`
// contains filtered or unexported fields
}
func (*OutputSchema) Descriptor
deprecated
func (*OutputSchema) Descriptor() ([]byte, []int)
Deprecated: Use OutputSchema.ProtoReflect.Descriptor instead.
func (*OutputSchema) GetDescription ¶
func (x *OutputSchema) GetDescription() string
func (*OutputSchema) GetName ¶
func (x *OutputSchema) GetName() string
func (*OutputSchema) GetType ¶
func (x *OutputSchema) GetType() string
func (*OutputSchema) ProtoMessage ¶
func (*OutputSchema) ProtoMessage()
func (*OutputSchema) ProtoReflect ¶
func (x *OutputSchema) ProtoReflect() protoreflect.Message
func (*OutputSchema) Reset ¶
func (x *OutputSchema) Reset()
func (*OutputSchema) String ¶
func (x *OutputSchema) String() string
type PluginServiceClient ¶
type PluginServiceClient interface {
GetInfo(ctx context.Context, in *GetInfoRequest, opts ...grpc.CallOption) (*GetInfoResponse, error)
Init(ctx context.Context, in *InitRequest, opts ...grpc.CallOption) (*InitResponse, error)
Shutdown(ctx context.Context, in *ShutdownRequest, opts ...grpc.CallOption) (*ShutdownResponse, error)
}
PluginServiceClient is the client API for PluginService service.
For semantics around ctx use and closing/ending streaming RPCs, please refer to https://pkg.go.dev/google.golang.org/grpc/?tab=doc#ClientConn.NewStream.
func NewPluginServiceClient ¶
func NewPluginServiceClient(cc grpc.ClientConnInterface) PluginServiceClient
type PluginServiceServer ¶
type PluginServiceServer interface {
GetInfo(context.Context, *GetInfoRequest) (*GetInfoResponse, error)
Init(context.Context, *InitRequest) (*InitResponse, error)
Shutdown(context.Context, *ShutdownRequest) (*ShutdownResponse, error)
// contains filtered or unexported methods
}
PluginServiceServer is the server API for PluginService service. All implementations must embed UnimplementedPluginServiceServer for forward compatibility.
type Severity ¶ added in v0.5.0
type Severity int32
Severity of a validation issue. SEVERITY_UNSPECIFIED (proto3 zero value) is treated as ERROR by the host.
func (Severity) Descriptor ¶ added in v0.5.0
func (Severity) Descriptor() protoreflect.EnumDescriptor
func (Severity) EnumDescriptor
deprecated
added in
v0.5.0
func (Severity) Number ¶ added in v0.5.0
func (x Severity) Number() protoreflect.EnumNumber
func (Severity) Type ¶ added in v0.5.0
func (Severity) Type() protoreflect.EnumType
type ShutdownRequest ¶
type ShutdownRequest struct {
// contains filtered or unexported fields
}
func (*ShutdownRequest) Descriptor
deprecated
func (*ShutdownRequest) Descriptor() ([]byte, []int)
Deprecated: Use ShutdownRequest.ProtoReflect.Descriptor instead.
func (*ShutdownRequest) ProtoMessage ¶
func (*ShutdownRequest) ProtoMessage()
func (*ShutdownRequest) ProtoReflect ¶
func (x *ShutdownRequest) ProtoReflect() protoreflect.Message
func (*ShutdownRequest) Reset ¶
func (x *ShutdownRequest) Reset()
func (*ShutdownRequest) String ¶
func (x *ShutdownRequest) String() string
type ShutdownResponse ¶
type ShutdownResponse struct {
// contains filtered or unexported fields
}
func (*ShutdownResponse) Descriptor
deprecated
func (*ShutdownResponse) Descriptor() ([]byte, []int)
Deprecated: Use ShutdownResponse.ProtoReflect.Descriptor instead.
func (*ShutdownResponse) ProtoMessage ¶
func (*ShutdownResponse) ProtoMessage()
func (*ShutdownResponse) ProtoReflect ¶
func (x *ShutdownResponse) ProtoReflect() protoreflect.Message
func (*ShutdownResponse) Reset ¶
func (x *ShutdownResponse) Reset()
func (*ShutdownResponse) String ¶
func (x *ShutdownResponse) String() string
type StepTypeInfo ¶ added in v0.5.0
type StepTypeInfo struct {
Name string `protobuf:"bytes,1,opt,name=name,proto3" json:"name,omitempty"`
Description string `protobuf:"bytes,2,opt,name=description,proto3" json:"description,omitempty"`
// contains filtered or unexported fields
}
func (*StepTypeInfo) Descriptor
deprecated
added in
v0.5.0
func (*StepTypeInfo) Descriptor() ([]byte, []int)
Deprecated: Use StepTypeInfo.ProtoReflect.Descriptor instead.
func (*StepTypeInfo) GetDescription ¶ added in v0.5.0
func (x *StepTypeInfo) GetDescription() string
func (*StepTypeInfo) GetName ¶ added in v0.5.0
func (x *StepTypeInfo) GetName() string
func (*StepTypeInfo) ProtoMessage ¶ added in v0.5.0
func (*StepTypeInfo) ProtoMessage()
func (*StepTypeInfo) ProtoReflect ¶ added in v0.5.0
func (x *StepTypeInfo) ProtoReflect() protoreflect.Message
func (*StepTypeInfo) Reset ¶ added in v0.5.0
func (x *StepTypeInfo) Reset()
func (*StepTypeInfo) String ¶ added in v0.5.0
func (x *StepTypeInfo) String() string
type StepTypeServiceClient ¶ added in v0.5.0
type StepTypeServiceClient interface {
ListStepTypes(ctx context.Context, in *ListStepTypesRequest, opts ...grpc.CallOption) (*ListStepTypesResponse, error)
ExecuteStep(ctx context.Context, in *ExecuteStepRequest, opts ...grpc.CallOption) (*ExecuteStepResponse, error)
}
StepTypeServiceClient is the client API for StepTypeService service.
For semantics around ctx use and closing/ending streaming RPCs, please refer to https://pkg.go.dev/google.golang.org/grpc/?tab=doc#ClientConn.NewStream.
func NewStepTypeServiceClient ¶ added in v0.5.0
func NewStepTypeServiceClient(cc grpc.ClientConnInterface) StepTypeServiceClient
type StepTypeServiceServer ¶ added in v0.5.0
type StepTypeServiceServer interface {
ListStepTypes(context.Context, *ListStepTypesRequest) (*ListStepTypesResponse, error)
ExecuteStep(context.Context, *ExecuteStepRequest) (*ExecuteStepResponse, error)
// contains filtered or unexported methods
}
StepTypeServiceServer is the server API for StepTypeService service. All implementations must embed UnimplementedStepTypeServiceServer for forward compatibility.
type UnimplementedOperationServiceServer ¶
type UnimplementedOperationServiceServer struct{}
UnimplementedOperationServiceServer must be embedded to have forward compatible implementations.
NOTE: this should be embedded by value instead of pointer to avoid a nil pointer dereference when methods are called.
func (UnimplementedOperationServiceServer) Execute ¶
func (UnimplementedOperationServiceServer) Execute(context.Context, *ExecuteRequest) (*ExecuteResponse, error)
func (UnimplementedOperationServiceServer) GetOperation ¶
func (UnimplementedOperationServiceServer) GetOperation(context.Context, *GetOperationRequest) (*GetOperationResponse, error)
func (UnimplementedOperationServiceServer) ListOperations ¶
func (UnimplementedOperationServiceServer) ListOperations(context.Context, *ListOperationsRequest) (*ListOperationsResponse, error)
type UnimplementedPluginServiceServer ¶
type UnimplementedPluginServiceServer struct{}
UnimplementedPluginServiceServer must be embedded to have forward compatible implementations.
NOTE: this should be embedded by value instead of pointer to avoid a nil pointer dereference when methods are called.
func (UnimplementedPluginServiceServer) GetInfo ¶
func (UnimplementedPluginServiceServer) GetInfo(context.Context, *GetInfoRequest) (*GetInfoResponse, error)
func (UnimplementedPluginServiceServer) Init ¶
func (UnimplementedPluginServiceServer) Init(context.Context, *InitRequest) (*InitResponse, error)
func (UnimplementedPluginServiceServer) Shutdown ¶
func (UnimplementedPluginServiceServer) Shutdown(context.Context, *ShutdownRequest) (*ShutdownResponse, error)
type UnimplementedStepTypeServiceServer ¶ added in v0.5.0
type UnimplementedStepTypeServiceServer struct{}
UnimplementedStepTypeServiceServer must be embedded to have forward compatible implementations.
NOTE: this should be embedded by value instead of pointer to avoid a nil pointer dereference when methods are called.
func (UnimplementedStepTypeServiceServer) ExecuteStep ¶ added in v0.5.0
func (UnimplementedStepTypeServiceServer) ExecuteStep(context.Context, *ExecuteStepRequest) (*ExecuteStepResponse, error)
func (UnimplementedStepTypeServiceServer) ListStepTypes ¶ added in v0.5.0
func (UnimplementedStepTypeServiceServer) ListStepTypes(context.Context, *ListStepTypesRequest) (*ListStepTypesResponse, error)
type UnimplementedValidatorServiceServer ¶ added in v0.5.0
type UnimplementedValidatorServiceServer struct{}
UnimplementedValidatorServiceServer must be embedded to have forward compatible implementations.
NOTE: this should be embedded by value instead of pointer to avoid a nil pointer dereference when methods are called.
func (UnimplementedValidatorServiceServer) ValidateStep ¶ added in v0.5.0
func (UnimplementedValidatorServiceServer) ValidateStep(context.Context, *ValidateStepRequest) (*ValidateStepResponse, error)
func (UnimplementedValidatorServiceServer) ValidateWorkflow ¶ added in v0.5.0
func (UnimplementedValidatorServiceServer) ValidateWorkflow(context.Context, *ValidateWorkflowRequest) (*ValidateWorkflowResponse, error)
type UnsafeOperationServiceServer ¶
type UnsafeOperationServiceServer interface {
// contains filtered or unexported methods
}
UnsafeOperationServiceServer may be embedded to opt out of forward compatibility for this service. Use of this interface is not recommended, as added methods to OperationServiceServer will result in compilation errors.
type UnsafePluginServiceServer ¶
type UnsafePluginServiceServer interface {
// contains filtered or unexported methods
}
UnsafePluginServiceServer may be embedded to opt out of forward compatibility for this service. Use of this interface is not recommended, as added methods to PluginServiceServer will result in compilation errors.
type UnsafeStepTypeServiceServer ¶ added in v0.5.0
type UnsafeStepTypeServiceServer interface {
// contains filtered or unexported methods
}
UnsafeStepTypeServiceServer may be embedded to opt out of forward compatibility for this service. Use of this interface is not recommended, as added methods to StepTypeServiceServer will result in compilation errors.
type UnsafeValidatorServiceServer ¶ added in v0.5.0
type UnsafeValidatorServiceServer interface {
// contains filtered or unexported methods
}
UnsafeValidatorServiceServer may be embedded to opt out of forward compatibility for this service. Use of this interface is not recommended, as added methods to ValidatorServiceServer will result in compilation errors.
type ValidateStepRequest ¶ added in v0.5.0
type ValidateStepRequest struct {
WorkflowJson []byte `protobuf:"bytes,1,opt,name=workflow_json,json=workflowJson,proto3" json:"workflow_json,omitempty"`
StepName string `protobuf:"bytes,2,opt,name=step_name,json=stepName,proto3" json:"step_name,omitempty"`
// contains filtered or unexported fields
}
func (*ValidateStepRequest) Descriptor
deprecated
added in
v0.5.0
func (*ValidateStepRequest) Descriptor() ([]byte, []int)
Deprecated: Use ValidateStepRequest.ProtoReflect.Descriptor instead.
func (*ValidateStepRequest) GetStepName ¶ added in v0.5.0
func (x *ValidateStepRequest) GetStepName() string
func (*ValidateStepRequest) GetWorkflowJson ¶ added in v0.5.0
func (x *ValidateStepRequest) GetWorkflowJson() []byte
func (*ValidateStepRequest) ProtoMessage ¶ added in v0.5.0
func (*ValidateStepRequest) ProtoMessage()
func (*ValidateStepRequest) ProtoReflect ¶ added in v0.5.0
func (x *ValidateStepRequest) ProtoReflect() protoreflect.Message
func (*ValidateStepRequest) Reset ¶ added in v0.5.0
func (x *ValidateStepRequest) Reset()
func (*ValidateStepRequest) String ¶ added in v0.5.0
func (x *ValidateStepRequest) String() string
type ValidateStepResponse ¶ added in v0.5.0
type ValidateStepResponse struct {
Issues []*ValidationIssue `protobuf:"bytes,1,rep,name=issues,proto3" json:"issues,omitempty"`
// contains filtered or unexported fields
}
func (*ValidateStepResponse) Descriptor
deprecated
added in
v0.5.0
func (*ValidateStepResponse) Descriptor() ([]byte, []int)
Deprecated: Use ValidateStepResponse.ProtoReflect.Descriptor instead.
func (*ValidateStepResponse) GetIssues ¶ added in v0.5.0
func (x *ValidateStepResponse) GetIssues() []*ValidationIssue
func (*ValidateStepResponse) ProtoMessage ¶ added in v0.5.0
func (*ValidateStepResponse) ProtoMessage()
func (*ValidateStepResponse) ProtoReflect ¶ added in v0.5.0
func (x *ValidateStepResponse) ProtoReflect() protoreflect.Message
func (*ValidateStepResponse) Reset ¶ added in v0.5.0
func (x *ValidateStepResponse) Reset()
func (*ValidateStepResponse) String ¶ added in v0.5.0
func (x *ValidateStepResponse) String() string
type ValidateWorkflowRequest ¶ added in v0.5.0
type ValidateWorkflowRequest struct {
WorkflowJson []byte `protobuf:"bytes,1,opt,name=workflow_json,json=workflowJson,proto3" json:"workflow_json,omitempty"`
// contains filtered or unexported fields
}
func (*ValidateWorkflowRequest) Descriptor
deprecated
added in
v0.5.0
func (*ValidateWorkflowRequest) Descriptor() ([]byte, []int)
Deprecated: Use ValidateWorkflowRequest.ProtoReflect.Descriptor instead.
func (*ValidateWorkflowRequest) GetWorkflowJson ¶ added in v0.5.0
func (x *ValidateWorkflowRequest) GetWorkflowJson() []byte
func (*ValidateWorkflowRequest) ProtoMessage ¶ added in v0.5.0
func (*ValidateWorkflowRequest) ProtoMessage()
func (*ValidateWorkflowRequest) ProtoReflect ¶ added in v0.5.0
func (x *ValidateWorkflowRequest) ProtoReflect() protoreflect.Message
func (*ValidateWorkflowRequest) Reset ¶ added in v0.5.0
func (x *ValidateWorkflowRequest) Reset()
func (*ValidateWorkflowRequest) String ¶ added in v0.5.0
func (x *ValidateWorkflowRequest) String() string
type ValidateWorkflowResponse ¶ added in v0.5.0
type ValidateWorkflowResponse struct {
Issues []*ValidationIssue `protobuf:"bytes,1,rep,name=issues,proto3" json:"issues,omitempty"`
// contains filtered or unexported fields
}
func (*ValidateWorkflowResponse) Descriptor
deprecated
added in
v0.5.0
func (*ValidateWorkflowResponse) Descriptor() ([]byte, []int)
Deprecated: Use ValidateWorkflowResponse.ProtoReflect.Descriptor instead.
func (*ValidateWorkflowResponse) GetIssues ¶ added in v0.5.0
func (x *ValidateWorkflowResponse) GetIssues() []*ValidationIssue
func (*ValidateWorkflowResponse) ProtoMessage ¶ added in v0.5.0
func (*ValidateWorkflowResponse) ProtoMessage()
func (*ValidateWorkflowResponse) ProtoReflect ¶ added in v0.5.0
func (x *ValidateWorkflowResponse) ProtoReflect() protoreflect.Message
func (*ValidateWorkflowResponse) Reset ¶ added in v0.5.0
func (x *ValidateWorkflowResponse) Reset()
func (*ValidateWorkflowResponse) String ¶ added in v0.5.0
func (x *ValidateWorkflowResponse) String() string
type ValidationIssue ¶ added in v0.5.0
type ValidationIssue struct {
Severity Severity `protobuf:"varint,1,opt,name=severity,proto3,enum=plugin.v1.Severity" json:"severity,omitempty"`
Message string `protobuf:"bytes,2,opt,name=message,proto3" json:"message,omitempty"`
Step string `protobuf:"bytes,3,opt,name=step,proto3" json:"step,omitempty"`
Field string `protobuf:"bytes,4,opt,name=field,proto3" json:"field,omitempty"`
// contains filtered or unexported fields
}
func (*ValidationIssue) Descriptor
deprecated
added in
v0.5.0
func (*ValidationIssue) Descriptor() ([]byte, []int)
Deprecated: Use ValidationIssue.ProtoReflect.Descriptor instead.
func (*ValidationIssue) GetField ¶ added in v0.5.0
func (x *ValidationIssue) GetField() string
func (*ValidationIssue) GetMessage ¶ added in v0.5.0
func (x *ValidationIssue) GetMessage() string
func (*ValidationIssue) GetSeverity ¶ added in v0.5.0
func (x *ValidationIssue) GetSeverity() Severity
func (*ValidationIssue) GetStep ¶ added in v0.5.0
func (x *ValidationIssue) GetStep() string
func (*ValidationIssue) ProtoMessage ¶ added in v0.5.0
func (*ValidationIssue) ProtoMessage()
func (*ValidationIssue) ProtoReflect ¶ added in v0.5.0
func (x *ValidationIssue) ProtoReflect() protoreflect.Message
func (*ValidationIssue) Reset ¶ added in v0.5.0
func (x *ValidationIssue) Reset()
func (*ValidationIssue) String ¶ added in v0.5.0
func (x *ValidationIssue) String() string
type ValidatorServiceClient ¶ added in v0.5.0
type ValidatorServiceClient interface {
ValidateWorkflow(ctx context.Context, in *ValidateWorkflowRequest, opts ...grpc.CallOption) (*ValidateWorkflowResponse, error)
ValidateStep(ctx context.Context, in *ValidateStepRequest, opts ...grpc.CallOption) (*ValidateStepResponse, error)
}
ValidatorServiceClient is the client API for ValidatorService service.
For semantics around ctx use and closing/ending streaming RPCs, please refer to https://pkg.go.dev/google.golang.org/grpc/?tab=doc#ClientConn.NewStream.
func NewValidatorServiceClient ¶ added in v0.5.0
func NewValidatorServiceClient(cc grpc.ClientConnInterface) ValidatorServiceClient
type ValidatorServiceServer ¶ added in v0.5.0
type ValidatorServiceServer interface {
ValidateWorkflow(context.Context, *ValidateWorkflowRequest) (*ValidateWorkflowResponse, error)
ValidateStep(context.Context, *ValidateStepRequest) (*ValidateStepResponse, error)
// contains filtered or unexported methods
}
ValidatorServiceServer is the server API for ValidatorService service. All implementations must embed UnimplementedValidatorServiceServer for forward compatibility.